/**
	Character class
	JDG Communications for Federal Trade Commission
*/

import mx.utils.Delegate;

import gs.TweenMax;
import gs.plugins.TweenPlugin;
import gs.plugins.ColorTransformPlugin;
import gs.TweenGroup;

import gov.ftc.core.Utilities;
import gov.ftc.squaresgame.templates.BasicClip;

class gov.ftc.squaresgame.Character extends BasicClip {

// CLASS VARIABLES

	public var border:MovieClip;
	public var body:MovieClip;
	public var legs:MovieClip;
	
	private var __isDim:Boolean;
	private var __isMarked:String;
	public var id:Number;
	
	private var __flashInt:Number;
	private var __borderMode:String;
	

// CONSTRUCTOR
	
	public function Character() {
		super();

		setData("character");
		onRollOver = Delegate.create(this, doRollOver);
		onRollOut = Delegate.create(this, doRollOut);
		onRelease = Delegate.create(this, doRelease);
		onReleaseOutside = Delegate.create(this, doRollOut);
		useHandCursor = false;
		
		__isDim = false;
		__isMarked = null;

		TweenPlugin.activate([ColorTransformPlugin]);
	}
	
// CLASS METHODS

	public function init():Void {
		//called after setData() 
		super.init();
	}

	private function doRollOver():Void {
		if (!__isDim && !__isMarked) {
			__gc.gameBroadcaster.broadcastMessage("characterMouseEvent", "rollOver", this);
		}
	}
	
	private function doRollOut():Void {
		if (!__isDim && !__isMarked) {
			__gc.gameBroadcaster.broadcastMessage("characterMouseEvent", "rollOut", this);
		}
	}

	private function doRelease():Void {
		if (!__isDim && !__isMarked) {
			__gc.gameBroadcaster.broadcastMessage("characterMouseEvent", "release", this);
		}
	}
	
	public function showBorderMode(p_mode:String):Void {
		clearInterval(__flashInt);
		TweenMax.to(border, 0.2, {colorTransform:{tint: __gd.borderColors[p_mode], tintAmount: 1}});
		__borderMode = p_mode;
	}
	
	public function dim(p_mode:Boolean):Void {
		flashBorder(false);
		__isDim = p_mode;
		var tweenVars:Object = {
			colorTransform:{tint:0x000000,
			tintAmount: 0.45}
		}
		if (p_mode == false) tweenVars.colorTransform.tintAmount = 0;
		TweenMax.to(this, 0.3, tweenVars);
	}
	
	public function mark(p_mode:Number):Void {
		switch (p_mode) {
			case 1:
				__isMarked = "markedX";
				body.cname._visible = false;
				body.screen.gotoAndStop(2);
				showBorderMode("markedX");
				break;
			case 2:
				__isMarked = "markedO";
				body.cname._visible = false;
				body.screen.gotoAndStop(3);
				showBorderMode("markedO");
				break;
			default:
				__isMarked = null;
				body.cname._visible = true;
				body.screen.gotoAndStop(1);
				showBorderMode("idle");
		}
	}
	
	public function flashBorder(p_mode:Boolean, p_player:Number):Void {
		var flashMode:String;
		switch (p_player) {
			case 1:
				flashMode = "markedX";
				break;
			case 2:
				flashMode = "markedO";
				break;
		}
		if (p_mode) {
			__flashInt = setInterval(this, "toggleFlashBorder", __gd.borderFlashRate*1000, [flashMode]);
		} else {
			clearInterval(__flashInt);
			showBorderMode(__isMarked || "idle");
		}
	}
	
	private function toggleFlashBorder(p_flashMode:String):Void {
		var newMode:String = (p_flashMode != __borderMode) ? p_flashMode : "idle";
		__borderMode = newMode;
		TweenMax.to(border, 0, {colorTransform:{tint: __gd.borderColors[newMode], tintAmount: 1}});
	}
	
	public function wiggle(p_mode:String):Void {
		if (p_mode == "in") {
			TweenMax.to(body, 0.15, {_rotation: 3});
		} else {
			TweenMax.to(body, 0.15, {_rotation: 0});
		}
	}

	
	public function destroy():Void {
		this.onEnterFrame = null;
		TweenMax.killTweensOf(this);
	}
	
}